==> cargo-binstall-1.17.3-1.src.tar.gz: cargo-binstall-1.17.3/crates/binstalk-bins/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.6.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.14...binstalk-bins-v0.6.15) - 2025-09-06

### Other

- updated the following local packages: atomic-file-install
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.6.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.20...binstalk-bins-v0.6.21) - 2026-01-23

### Other

- updated the following local packages: binstalk-types

## [0.6.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.19...binstalk-bins-v0.6.20) - 2026-01-18

### Other

- updated the following local packages: binstalk-types

## [0.6.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.18...binstalk-bins-v0.6.19) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.6.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.17...binstalk-bins-v0.6.18) - 2025-11-15

### Other

- updated the following local packages: binstalk-types

## [0.6.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.16...binstalk-bins-v0.6.17) - 2025-11-05

### Other

- updated the following local packages: atomic-file-install

## [0.6.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.15...binstalk-bins-v0.6.16) - 2025-10-24

### Other

- updated the following local packages: binstalk-types

## [0.6.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.13...binstalk-bins-v0.6.14) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.6.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.12...binstalk-bins-v0.6.13) - 2025-03-19

### Other

- updated the following local packages: atomic-file-install

## [0.6.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.11...binstalk-bins-v0.6.12) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.6.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.10...binstalk-bins-v0.6.11) - 2025-02-22

### Other

- updated the following local packages: atomic-file-install

## [0.6.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.9...binstalk-bins-v0.6.10) - 2025-02-11

### Other

- updated the following local packages: binstalk-types

## [0.6.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.8...binstalk-bins-v0.6.9) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.6.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.7...binstalk-bins-v0.6.8) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.6.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.6...binstalk-bins-v0.6.7) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.6.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.5...binstalk-bins-v0.6.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.6.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.4...binstalk-bins-v0.6.5) - 2024-11-23

### Other

- updated the following local packages: binstalk-types

## [0.6.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.3...binstalk-bins-v0.6.4) - 2024-11-18

### Other

- updated the following local packages: atomic-file-install

## [0.6.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.2...binstalk-bins-v0.6.3) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.6.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.1...binstalk-bins-v0.6.2) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.6.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.0...binstalk-bins-v0.6.1) - 2024-11-02

### Other

- Improve UI orompt for installation ([#1950](https://github.com/cargo-bins/cargo-binstall/pull/1950))

## [0.6.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.5.0...binstalk-bins-v0.6.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types

==> cargo-binstall-1.17.4-1.src.tar.gz: cargo-binstall-1.17.4/crates/binstalk-bins/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.6.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.21...binstalk-bins-v0.6.22) - 2026-01-27

### Other

- Fix changelog format ([#2454](https://github.com/cargo-bins/cargo-binstall/pull/2454))

## [0.6.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.20...binstalk-bins-v0.6.21) - 2026-01-23

### Other

- updated the following local packages: binstalk-types

## [0.6.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.19...binstalk-bins-v0.6.20) - 2026-01-18

### Other

- updated the following local packages: binstalk-types

## [0.6.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.18...binstalk-bins-v0.6.19) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.6.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.17...binstalk-bins-v0.6.18) - 2025-11-15

### Other

- updated the following local packages: binstalk-types

## [0.6.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.16...binstalk-bins-v0.6.17) - 2025-11-05

### Other

- updated the following local packages: atomic-file-install

## [0.6.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.15...binstalk-bins-v0.6.16) - 2025-10-24

### Other

- updated the following local packages: binstalk-types

## [0.6.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.14...binstalk-bins-v0.6.15) - 2025-09-06

### Other

- updated the following local packages: atomic-file-install

## [0.6.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.13...binstalk-bins-v0.6.14) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.6.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.12...binstalk-bins-v0.6.13) - 2025-03-19

### Other

- updated the following local packages: atomic-file-install

## [0.6.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.11...binstalk-bins-v0.6.12) - 2025-03-07

### Other

- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.6.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.10...binstalk-bins-v0.6.11) - 2025-02-22

### Other

- updated the following local packages: atomic-file-install

## [0.6.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.9...binstalk-bins-v0.6.10) - 2025-02-11

### Other

- updated the following local packages: binstalk-types

## [0.6.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.8...binstalk-bins-v0.6.9) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.6.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.7...binstalk-bins-v0.6.8) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.6.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.6...binstalk-bins-v0.6.7) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.6.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.5...binstalk-bins-v0.6.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.6.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.4...binstalk-bins-v0.6.5) - 2024-11-23

### Other

- updated the following local packages: binstalk-types

## [0.6.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.3...binstalk-bins-v0.6.4) - 2024-11-18

### Other

- updated the following local packages: atomic-file-install

## [0.6.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.2...binstalk-bins-v0.6.3) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.6.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.1...binstalk-bins-v0.6.2) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.6.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.6.0...binstalk-bins-v0.6.1) - 2024-11-02

### Other

- Improve UI orompt for installation ([#1950](https://github.com/cargo-bins/cargo-binstall/pull/1950))

## [0.6.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-bins-v0.5.0...binstalk-bins-v0.6.0) - 2024-08-10

### Other
- updated the following local packages: binstalk-types
